//
//  MyWindow.m
//  CGSSecrets
//
//  Created by Dave Jewell on 06/02/2009.
//  Copyright 2009 Cocoa Secrets. All rights reserved.
//

#import "MyWindow.h"
#import "CGSPrivate.h"

@implementation MyWindow

- (void) awakeFromNib
{
	[NSTimer scheduledTimerWithTimeInterval: 1.0 target: self selector: @selector (update) userInfo: nil repeats: YES];
}

- (CGSConnection) finderConnection
{
	ProcessSerialNumber psn;
	CGSConnection result = 0;
	psn.highLongOfPSN = psn.lowLongOfPSN = 0;
	while (GetNextProcess (&psn) == noErr)
	{
		NSDictionary * processDict = (NSDictionary *) ProcessInformationCopyDictionary (&psn, kProcessDictionaryIncludeAllInformationMask);
		if ([[processDict objectForKey: (NSString *) kCFBundleIdentifierKey] isEqual: @"com.apple.finder"])
		{
			if (CGSGetConnectionIDForPSN (CGSDefaultConnection, &psn, &result) != noErr) result = 0;
			break;
		}
	}
	
	return result;
}

// Thanks to http://forums.realsoftware.com/viewtopic.php?p=6842 for the inspiration! :-)

- (void) update
{
	CGSConnection finder = [self finderConnection];
	NSInteger finderWindowCount = 0;
	if (finder && CGSGetOnScreenWindowCount (CGSDefaultConnection, finder, &finderWindowCount) == 0)
	{
		NSInteger idx;
		CGSWindow * buff = calloc (finderWindowCount, sizeof (CGSWindow));
		if (CGSGetOnScreenWindowList (CGSDefaultConnection, finder, finderWindowCount, buff, &finderWindowCount) == 0)
			for (idx = 0; idx < finderWindowCount; idx++)
			{
				NSString * prop;
				if (CGSGetWindowProperty (CGSDefaultConnection, buff [idx], (CGSValue) kCGSWindowTitle, (CGSValue *) &prop) == noErr)
				{
					// Some Finder windows have weird names - don't display the weird stuff....
					if ([prop length] && [prop isEqual: @" "] == NO) NSLog  (prop);
				}
			}
		
		free (buff);
	}
}

- (IBAction) preventActivation: (id) sender
{
	CGSSetPreventsActivation (CGSDefaultConnection, [self windowNumber], [sender state]);
}

- (IBAction) ignoresCycle: (id) sender
{
	CGSSetIgnoresCycle (CGSDefaultConnection, [self windowNumber], [sender state]);
}

- (IBAction) ignoreAsFrontWindow: (id) sender
{
	CGSSetIgnoreAsFrontWindow (CGSDefaultConnection, [self windowNumber], [sender state]);
}

- (IBAction) deferOrdering: (id) sender
{
	CGSSetDeferOrdering (CGSDefaultConnection, [self windowNumber], [sender state]);
}

- (IBAction) deferActivation: (id) sender
{
	CGSSetDeferActivation (CGSDefaultConnection, [self windowNumber], [sender state]);
}


@end
